@@ -59,10 +59,14 @@ class KSMainWindow: public QDialog
     void showPreferencesDialog();
     void showImageSharedFeedback(bool error, const QString &message);
     void imageCopied();
+    void imageSavedAndLocationCopied(const QUrl &location);
     void init();
     void setDefaultSaveAction();
+    void setDefaultCopyAction();
     void save();
     void saveAs();
+    void copyImage();
+    void copyLocation();
     void restoreWindowTitle();
 
     public Q_SLOTS:
@@ -80,11 +84,11 @@ class KSMainWindow: public QDialog
     protected:
 
     void moveEvent(QMoveEvent *event) override;
+    QSize sizeHint() const override;
 
     private:
 
     void keyPressEvent(QKeyEvent *event) override;
-    void copy();
 
     KSWidget         *mKSWidget;
     QFrame           *mDivider;
@@ -93,6 +97,9 @@ class KSMainWindow: public QDialog
     QPushButton      *mToolsButton;
     QPushButton      *mSendToButton;
     QToolButton      *mClipboardButton;
+    QMenu            *mClipboardMenu;
+    QAction          *mClipboardLocationAction;
+    QAction          *mClipboardImageAction;
     QToolButton      *mSaveButton;
     QMenu            *mSaveMenu;
     QAction          *mSaveAsAction;
